@@ -112,6 +112,7 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
     print("     --- start matching")
     matched_battery_level_list = []
     matched_charging_status_list = []
+    matched_time_list = []
 
     for idx in prompt_local_datetime_series.index:
         prompt_time = prompt_local_datetime_series[idx]
@@ -120,6 +121,7 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         if df_logs_combined.shape[0] == 0:
             battery_level = np.nan
             charging_status = np.nan
+            closest_time = np.nan
         else:
             subset_time_list = list(df_logs_combined["Local_Timestamp"])
 
@@ -130,10 +132,11 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
             charging_status = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
                                        "isCharging"])[0]
 
+        matched_time_list.append(closest_time)
         matched_battery_level_list.append(battery_level)
         matched_charging_status_list.append(charging_status)
 
-    return matched_battery_level_list, matched_charging_status_list
+    return matched_battery_level_list, matched_charging_status_list, matched_time_list
 
 
 def transform(battery_level_column):
@@ -149,13 +152,14 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
 
     if df_logs_combined.shape[0] > 0:
         # Match the combined parsed intermediate file with prompt feature data frame
-        battery_level_column, charging_status_column = match_feature(prompt_local_datetime_series, df_logs_combined)
+        battery_level_column, charging_status_column, match_time = match_feature(prompt_local_datetime_series, df_logs_combined)
     else:
         battery_level_column = ["NF"] * len(prompt_local_datetime_series)
         charging_status_column = ["NF"] * len(prompt_local_datetime_series)
+        match_time = ["NF"] * len(prompt_local_datetime_series)
 
     # transform feature
     battery_level_column_transformed = transform(battery_level_column)
     print("     --- success")
 
-    return battery_level_column_transformed, charging_status_column
+    return battery_level_column_transformed, charging_status_column, match_time
