@@ -106,7 +106,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study, decr
         if len(csv_path_list) == 0:
             print("Cannot find logs file around {}".format(date_in_study))
             return df_logs_combined
-        
+
         csv_path = csv_path_list[0]
 
         # decryption
@@ -147,6 +147,7 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
     print("     --- start matching")
     matched_location_list = []
+    matched_time_list = []
 
     for idx in prompt_local_datetime_series.index:
         prompt_time = prompt_local_datetime_series[idx]
@@ -155,6 +156,7 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
         if df_logs_combined.shape[0] == 0:
             location = np.nan
+            closest_time = np.nan
         else:
             subset_time_list = list(df_logs_combined["LOCATION_TIME_DATETIME"])
 
@@ -166,10 +168,11 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
                                        "LONG"])[0]
             location = [lat, long]
 
+        matched_time_list.append(closest_time)
         matched_location_list.append(location)
 
 
-    return matched_location_list
+    return matched_location_list, matched_time_list
 
 
 # def reverse_geo_nominatim(lat, long):
@@ -197,15 +200,16 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
 
     if df_logs_combined.shape[0] > 0:
         # Match the combined parsed intermediate file with prompt feature data frame
-        location_column = match_feature(prompt_local_datetime_series, df_logs_combined)
+        location_column, match_time = match_feature(prompt_local_datetime_series, df_logs_combined)
     else:
         location_column = ["NF"] * len(prompt_local_datetime_series)
+        match_time= ["NF"] * len(prompt_local_datetime_series)
 
     # transform feature
     location_column_transformed = transform(location_column)
     print("     --- success")
 
-    return location_column_transformed
+    return location_column_transformed, match_time
 
 
 if __name__ == "__main__":
